@@ -144,9 +144,9 @@ def get_available_data():
 # ============================================================
 # JOBS AND SUBMISSION MANAGEMENT
 # ============================================================
-def get_jobs():
+def get_jobs(**kwargs):
     logger.info('Getting jobs...')
-    return get(JOBS_URL)
+    return get(JOBS_URL, **kwargs)
 
 
 def update_job_status(job_url, status):
@@ -156,18 +156,21 @@ def update_job_status(job_url, status):
     return put(job_url, json=job_json)
 
 
-def get_submissions(job_url=None):
+def get_submissions(job_url=None, current_round=None):
     """
     Gets a list of submissions made by the user requesting the list. Include job_url if you want to
     filter the list of submissions by url.
 
     :param str job_url: Job URL. This will filter the submissions by Job.
+    :param int current_round: Filter by current round 
     :return list: List of dict-like objects containing the submissions associated to the job_url.
     """
     # Filter submissions by job if job URL is provided
-    params = None
+    params = {}
     if job_url:
-        params = {'job': get_uuid_from_url(job_url)}
+        params['job'] = get_uuid_from_url(job_url)
+    if current_round:
+        params['round'] = current_round
 
     # Get list of submissions
     return get(SUBMISSIONS_URL, params=params)
