@@ -10,12 +10,12 @@ import tempfile
 TEMP_DIR = tempfile.gettempdir()
 
 # Set API Base url
-BASE_URL = 'http://epione-demo.inria.fr/fedbionet/'
+BASE_URL = 'https://epione-demo.inria.fr/fedbionet/'
 
 # Set urls
 ME_URL = urljoin(BASE_URL, 'me/')
 CLIENTS_URL = urljoin(BASE_URL, 'clients/')
-MODELS_URL = urljoin(BASE_URL, 'mode/l')
+MODELS_URL = urljoin(BASE_URL, 'model/')
 JOBS_URL = urljoin(BASE_URL, 'job/')
 SUBMISSIONS_URL = urljoin(BASE_URL, 'submission/')
 DATA_URL = urljoin(BASE_URL, 'data/')
